# Aggregation examples

Examples of how to use the earthkit-transforms.aggregate modules

```{toctree}
:caption: 'Notebooks'
:maxdepth: 1


notebooks/aggregate/temporal/01-era5-general-methods.ipynb
notebooks/aggregate/temporal/02-era5-daily-monthly-statistics.ipynb
notebooks/aggregate/temporal/03-seas5-daily-statistics.ipynb
notebooks/aggregate/climatology/01-era5-climatology.ipynb
notebooks/aggregate/climatology/02-era5-anomaly.ipynb
notebooks/aggregate/aggregate-spatial.ipynb
```
